@@ -25,6 +25,7 @@
 #include "repo-service.h"
 #include "api/api-error.h"
 #include "seafile-applet.h"
+#include "daemon-mgr.h"
 #include "account-mgr.h"
 #include "settings-mgr.h"
 #include "utils/utils.h"
@@ -453,7 +454,7 @@ void ExtCommandsHandler::handleGenShareLink(const QStringList& args, bool intern
 
 QString ExtCommandsHandler::handleListRepos(const QStringList& args)
 {
-    if (args.size() != 1) {
+    if (args.size() < 1) {
         return "";
     }
     bool ok;
@@ -462,13 +463,16 @@ QString ExtCommandsHandler::handleListRepos(const QStringList& args)
         return "";
     }
 
+    // In older versions of the shell ext it sends one argument (the
+    // cache timestamp) and expects to see exactly six fields.
+    bool new_version = args.size() > 1;
     QStringList infos;
     foreach (const LocalRepo& repo, listLocalRepos(ts)) {
         QStringList fields;
         QString file_lock = repo.account.isAtLeastProVersion(4, 3, 0)
                                 ? "file-lock-supported"
                                 : "file-lock-unsupported";
-        QString private_share = "private-share-supported";;
+        QString private_share = "private-share-supported";
         if (!repo.account.isPro()) {
             private_share = "private-share-unsupported";
         } else {
@@ -485,6 +489,18 @@ QString ExtCommandsHandler::handleListRepos(const QStringList& args)
                << repoStatus(repo)
                << file_lock
                << private_share;
+
+        if (new_version) {
+            QString internal_link_supported = repo.account.isAtLeastVersion(6, 3, 0)
+                ? "internal-link-supported"
+                : "internal-link-unsupported";
+
+            // Here we comment this out temporarily, and we would add
+            // it back when we release internal link in seafile
+            // community server 6.3.x.
+
+            // fields << internal_link_supported;
+        }
         infos << fields.join("\t");
     }
 
@@ -585,17 +601,30 @@ ReposInfoCache::ReposInfoCache(QObject * parent)
     : QObject(parent)
 {
     cache_ts_ = 0;
-    rpc_ = new SeafileRpcClient();
+    rpc_client_ = new SeafileRpcClient();
+    connect(seafApplet->daemonManager(), SIGNAL(daemonRestarted()), this, SLOT(onDaemonRestarted()));
 }
 
 void ReposInfoCache::start()
 {
-    rpc_->connectDaemon();
+    rpc_client_->tryConnectDaemon();
 }
 
+void ReposInfoCache::onDaemonRestarted()
+{
+    QMutexLocker lock(&rpc_client_mutex_);
+    qDebug("reviving message poller when daemon is restarted");
+    if (rpc_client_) {
+        delete rpc_client_;
+    }
+    rpc_client_ = new SeafileRpcClient();
+    rpc_client_->tryConnectDaemon();
+}
+
+
 QList<LocalRepo> ReposInfoCache::getReposInfo(quint64 ts)
 {
-    QMutexLocker lock(&rpc_mutex_);
+    QMutexLocker lock(&rpc_client_mutex_);
 
     // There are two levels of repos lists cache in the shell extension:
     // 1. The extension would cache the repos list in explorer side so it
@@ -614,12 +643,12 @@ QList<LocalRepo> ReposInfoCache::getReposInfo(quint64 ts)
     // qDebug("ReposInfoCache: fetch from daemon");
 
     std::vector<LocalRepo> repos;
-    rpc_->listLocalRepos(&repos);
+    rpc_client_->listLocalRepos(&repos);
 
     for (size_t i = 0; i < repos.size(); i++) {
         LocalRepo& repo = repos[i];
-        rpc_->getSyncStatus(repo);
-        repo.account = seafApplet->accountManager()->getAccountByRepo(repo.id, rpc_);
+        rpc_client_->getSyncStatus(repo);
+        repo.account = seafApplet->accountManager()->getAccountByRepo(repo.id, rpc_client_);
     }
 
     cached_info_ = QVector<LocalRepo>::fromStdVector(repos).toList();
@@ -633,6 +662,6 @@ bool ReposInfoCache::getRepoFileStatus(const QString& repo_id,
                                        bool isdir,
                                        QString *status)
 {
-    QMutexLocker lock(&rpc_mutex_);
-    return rpc_->getRepoFileStatus(repo_id, path_in_repo, isdir, status) == 0;
+    QMutexLocker lock(&rpc_client_mutex_);
+    return rpc_client_->getRepoFileStatus(repo_id, path_in_repo, isdir, status) == 0;
 }
